TempoEthApiBounds

Trait TempoEthApiBounds 

pub trait TempoEthApiBounds: RpcNodeCore<Primitives = TempoPrimitives, Pool: TransactionPool<Transaction: PoolTransaction<Pooled = TempoTxEnvelope>>, Evm: ConfigureEvm<Primitives = TempoPrimitives, BlockExecutorFactory: BlockExecutorFactory<EvmFactory: EvmFactory<Tx = TempoTxEnv, Spec = TempoHardfork, BlockEnv = TempoBlockEnv, HaltReason = TempoHaltReason, Error<EvmDatabaseError<ProviderError>> = EVMError<EvmDatabaseError<ProviderError>, TempoInvalidTransaction>>>>> { }
Helper trait that groups the component bounds required by TempoEthApi.

This trait has no methods. It exists so the generic Tempo RPC implementation and builder can name the required Tempo primitives, pooled transaction type, and EVM configuration in one place.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<N> TempoEthApiBounds for N
where N: RpcNodeCore<Primitives = TempoPrimitives, Pool: TransactionPool<Transaction: PoolTransaction<Pooled = TempoTxEnvelope>>, Evm: ConfigureEvm<Primitives = TempoPrimitives, BlockExecutorFactory: BlockExecutorFactory<EvmFactory: EvmFactory<Tx = TempoTxEnv, Spec = TempoHardfork, BlockEnv = TempoBlockEnv, HaltReason = TempoHaltReason, Error<EvmDatabaseError<ProviderError>> = EVMError<EvmDatabaseError<ProviderError>, TempoInvalidTransaction>>>>>,